@@ -12,6 +12,7 @@ import (
 
 	"github.com/h2non/filetype"
 	"github.com/mholt/archives"
+	"github.com/rs/zerolog"
 
 	"github.com/zricethezav/gitleaks/v8/config"
 	"github.com/zricethezav/gitleaks/v8/logging"
@@ -56,26 +57,33 @@ func (s *File) Fragments(ctx context.Context, yield FragmentsFunc) error {
 	// decide what to do with it.
 	if err == nil && format != nil {
 		if s.archiveDepth+1 > s.MaxArchiveDepth {
-			// Only warn when the feature is enabled
+			var event *zerolog.Event
+
+			// Warn if the feature is enabled; else emit a trace log.
 			if s.MaxArchiveDepth != 0 {
-				logging.Warn().Str(
-					"path", s.FullPath(),
-				).Int(
-					"max_archive_depth", s.MaxArchiveDepth,
-				).Msg("skipping archive: exceeds max archive depth")
+				event = logging.Warn()
+			} else {
+				event = logging.Trace()
 			}
+
+			event.Str(
+				"path", s.FullPath(),
+			).Int(
+				"max_archive_depth", s.MaxArchiveDepth,
+			).Msg("skipping archive: exceeds max archive depth")
+
 			return nil
 		}
 		if extractor, ok := format.(archives.Extractor); ok {
 			return s.extractorFragments(ctx, extractor, s.Content, yield)
 		}
 		if decompressor, ok := format.(archives.Decompressor); ok {
-			return s.decompressorFragments(decompressor, s.Content, yield)
+			return s.decompressorFragments(ctx, decompressor, s.Content, yield)
 		}
 		logging.Warn().Str("path", s.FullPath()).Msg("skipping unknown archive type")
 	}
 
-	return s.fileFragments(bufio.NewReader(s.Content), yield)
+	return s.fileFragments(ctx, bufio.NewReader(s.Content), yield)
 }
 
 // extractorFragments recursively crawls archives and yields fragments
@@ -139,14 +147,14 @@ func (s *File) extractorFragments(ctx context.Context, extractor archives.Extrac
 }
 
 // decompressorFragments recursively crawls archives and yields fragments
-func (s *File) decompressorFragments(decompressor archives.Decompressor, reader io.Reader, yield FragmentsFunc) error {
+func (s *File) decompressorFragments(ctx context.Context, decompressor archives.Decompressor, reader io.Reader, yield FragmentsFunc) error {
 	innerReader, err := decompressor.OpenReader(reader)
 	if err != nil {
 		logging.Error().Str("path", s.FullPath()).Msg("could read compressed file")
 		return nil
 	}
 
-	if err := s.fileFragments(bufio.NewReader(innerReader), yield); err != nil {
+	if err := s.fileFragments(ctx, bufio.NewReader(innerReader), yield); err != nil {
 		_ = innerReader.Close()
 		return err
 	}
@@ -156,7 +164,7 @@ func (s *File) decompressorFragments(decompressor archives.Decompressor, reader
 }
 
 // fileFragments reads the file into fragments to yield
-func (s *File) fileFragments(reader *bufio.Reader, yield FragmentsFunc) error {
+func (s *File) fileFragments(ctx context.Context, reader *bufio.Reader, yield FragmentsFunc) error {
 	// Create a buffer if the caller hasn't provided one
 	if s.Buffer == nil {
 		s.Buffer = make([]byte, defaultBufferSize)
@@ -164,75 +172,80 @@ func (s *File) fileFragments(reader *bufio.Reader, yield FragmentsFunc) error {
 
 	totalLines := 0
 	for {
-		fragment := Fragment{
-			FilePath: s.FullPath(),
-		}
-
-		n, err := reader.Read(s.Buffer)
-		if n == 0 {
-			if err != nil && err != io.EOF {
-				return yield(fragment, fmt.Errorf("could not read file: %w", err))
+		select {
+		case <-ctx.Done():
+			return ctx.Err()
+		default:
+			fragment := Fragment{
+				FilePath: s.FullPath(),
 			}
 
-			return nil
-		}
-
-		// Only check the filetype at the start of file.
-		if totalLines == 0 {
-			// TODO: could other optimizations be introduced here?
-			if mimetype, err := filetype.Match(s.Buffer[:n]); err != nil {
-				return yield(
-					fragment,
-					fmt.Errorf("could not read file: could not determine type: %w", err),
-				)
-			} else if mimetype.MIME.Type == "application" {
-				logging.Debug().
-					Str("mime_type", mimetype.MIME.Value).
-					Str("path", s.FullPath()).
-					Msgf("skipping binary file")
+			n, err := reader.Read(s.Buffer)
+			if n == 0 {
+				if err != nil && err != io.EOF {
+					return yield(fragment, fmt.Errorf("could not read file: %w", err))
+				}
 
 				return nil
 			}
-		}
 
-		// Try to split chunks across large areas of whitespace, if possible.
-		peekBuf := bytes.NewBuffer(s.Buffer[:n])
-		if err := readUntilSafeBoundary(reader, n, maxPeekSize, peekBuf); err != nil {
-			return yield(
-				fragment,
-				fmt.Errorf("could not read file: could not read until safe boundary: %w", err),
-			)
-		}
+			// Only check the filetype at the start of file.
+			if totalLines == 0 {
+				// TODO: could other optimizations be introduced here?
+				if mimetype, err := filetype.Match(s.Buffer[:n]); err != nil {
+					return yield(
+						fragment,
+						fmt.Errorf("could not read file: could not determine type: %w", err),
+					)
+				} else if mimetype.MIME.Type == "application" {
+					logging.Debug().
+						Str("mime_type", mimetype.MIME.Value).
+						Str("path", s.FullPath()).
+						Msgf("skipping binary file")
 
-		fragment.Raw = peekBuf.String()
-		fragment.Bytes = peekBuf.Bytes()
-		fragment.StartLine = totalLines + 1
+					return nil
+				}
+			}
 
-		// Count the number of newlines in this chunk
-		totalLines += strings.Count(fragment.Raw, "\n")
+			// Try to split chunks across large areas of whitespace, if possible.
+			peekBuf := bytes.NewBuffer(s.Buffer[:n])
+			if err := readUntilSafeBoundary(reader, n, maxPeekSize, peekBuf); err != nil {
+				return yield(
+					fragment,
+					fmt.Errorf("could not read file: could not read until safe boundary: %w", err),
+				)
+			}
 
-		if len(s.Symlink) > 0 {
-			fragment.SymlinkFile = s.Symlink
-		}
+			fragment.Raw = peekBuf.String()
+			fragment.Bytes = peekBuf.Bytes()
+			fragment.StartLine = totalLines + 1
 
-		if isWindows {
-			fragment.FilePath = filepath.ToSlash(fragment.FilePath)
-			fragment.SymlinkFile = filepath.ToSlash(s.Symlink)
-			fragment.WindowsFilePath = s.FullPath()
-		}
+			// Count the number of newlines in this chunk
+			totalLines += strings.Count(fragment.Raw, "\n")
 
-		// log errors but continue since there's content
-		if err != nil && err != io.EOF {
-			logging.Warn().Err(err).Msgf("issue reading file")
-		}
+			if len(s.Symlink) > 0 {
+				fragment.SymlinkFile = s.Symlink
+			}
 
-		// Done with the file!
-		if err == io.EOF {
-			return yield(fragment, nil)
-		}
+			if isWindows {
+				fragment.FilePath = filepath.ToSlash(fragment.FilePath)
+				fragment.SymlinkFile = filepath.ToSlash(s.Symlink)
+				fragment.WindowsFilePath = s.FullPath()
+			}
 
-		if err := yield(fragment, err); err != nil {
-			return err
+			// log errors but continue since there's content
+			if err != nil && err != io.EOF {
+				logging.Warn().Err(err).Msgf("issue reading file")
+			}
+
+			// Done with the file!
+			if err == io.EOF {
+				return yield(fragment, nil)
+			}
+
+			if err := yield(fragment, err); err != nil {
+				return err
+			}
 		}
 	}
 }
